//
//  IZLoginViewController.m
//  Instazam
//
//  Created by Isaac Schmidt on 4/12/12.
//  Copyright (c) 2012 Schmidt Consulting, LLC. All rights reserved.
//

#import "IZLoginViewController.h"

@interface IZLoginViewController ()

- (BOOL)validateTextFields;
- (BOOL)validateTextField:(UITextField *)field;
- (BOOL)validateDesiredPassword:(NSString *)password;
- (BOOL)validateDesiredEmailAddress:(NSString *)address;
- (BOOL)validateDesiredUserName:(NSString *)username;

@end

@implementation IZLoginViewController

@synthesize addressField = __addressField;
@synthesize addressLabel = __addressLabel;
@synthesize userNameLabel = __userNameLabel;
@synthesize userNameField = __userNameField;
@synthesize paswordLabel = __passwordLabel;
@synthesize passwordField = __passwordField;
@synthesize joinButton = __joinButton;
@synthesize joinStatusLabel = __joinStatusLabel;
@synthesize activityIndicator = __activityIndicator;
@synthesize addressStatusImageView = __addressStatusImageView;
@synthesize userNameStatusImageView = __userNameStatusImageView;
@synthesize passwordStatusImageView = __passwordStatusImageView;
@synthesize activeTextField = __activeTextField;

- (IBAction)didPressJoinButton:(id)sender
{
    PFUser *user = [PFUser user];
    user.username = self.userNameField.text;
    user.email = self.addressField.text;
    user.password = self.passwordField.text;
    
    if ([self validateTextFields]) 
    {
        [[self activityIndicator] startAnimating];
        
        [user signUpInBackgroundWithBlock:^(BOOL succeeded, NSError *error) {
            
            if (!error)
            {
                [[self joinStatusLabel] setText:@"Created account and logged in!"];
                [[self joinButton] setEnabled:NO];
                [[self activeTextField] resignFirstResponder];
            }
            else 
            {
                NSString *errorString = [[error userInfo] objectForKey:@"error"];
                errorString = [errorString capitalizedString];
                [[self joinStatusLabel] setText:errorString];
            }
            
            [[self activityIndicator] stopAnimating];
            
        }];
    }
    else 
    {
        UIAlertView *invalidAlert = [[UIAlertView alloc] initWithTitle:@"Input Error"
                                                               message:@"We cannot create an account with the information you've provided. Double-check your provided information."
                                                              delegate:nil
                                                     cancelButtonTitle:nil
                                                     otherButtonTitles:@"Ok", nil];
        [invalidAlert show];
    }
    
    
}

- (BOOL)validateTextFields
{
    BOOL valid = YES;
    
    if (![self validateTextField:[self addressField]])
    {
        valid = NO;
    }
    
    if (![self validateTextField:[self passwordField]])
    {
        valid = NO;
    }
    
    if (![self validateTextField:[self userNameField]])
    {
        valid = NO;
    }
    
    return valid;
    
}

- (BOOL)validateTextField:(UITextField *)field
{
    NSString *desiredString = [field text];
    BOOL valid = NO;
    UIImageView *validationImageView;
    
    if (field == [self userNameField])
    {
        valid = [self validateDesiredUserName:desiredString];
        validationImageView = [self userNameStatusImageView];
    }
    
    if (field == [self passwordField])
    {
        valid = [self validateDesiredPassword:desiredString];
        validationImageView = [self passwordStatusImageView];
    }
    
    if (field == [self addressField])
    {
        valid = [self validateDesiredEmailAddress:desiredString];
        validationImageView = [self addressStatusImageView];
    }
    
    if (valid)
    {
        [validationImageView setBackgroundColor:[UIColor greenColor]];
    }
    else {
        [validationImageView setBackgroundColor:[UIColor redColor]];
    }
    
    return valid;
}

- (BOOL)validateDesiredEmailAddress:(NSString *)address
{
    //Regular-expressions.info RFC 2822
    NSString *emailRegEx =
    @"(?:[a-z0-9!#$%\\&'*+/=?\\^_`{|}~-]+(?:\\.[a-z0-9!#$%\\&'*+/=?\\^_`{|}"
    @"~-]+)*|\"(?:[\\x01-\\x08\\x0b\\x0c\\x0e-\\x1f\\x21\\x23-\\x5b\\x5d-\\"
    @"x7f]|\\\\[\\x01-\\x09\\x0b\\x0c\\x0e-\\x7f])*\")@(?:(?:[a-z0-9](?:[a-"
    @"z0-9-]*[a-z0-9])?\\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|\\[(?:(?:25[0-5"
    @"]|2[0-4][0-9]|[01]?[0-9][0-9]?)\\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-"
    @"9][0-9]?|[a-z0-9-]*[a-z0-9]:(?:[\\x01-\\x08\\x0b\\x0c\\x0e-\\x1f\\x21"
    @"-\\x5a\\x53-\\x7f]|\\\\[\\x01-\\x09\\x0b\\x0c\\x0e-\\x7f])+)\\])";
    
    NSPredicate *regExPredicate = [NSPredicate predicateWithFormat:@"SELF MATCHES %@", emailRegEx];
    BOOL match = [regExPredicate evaluateWithObject:address];
    
    return match;
    
}

- (BOOL)validateDesiredPassword:(NSString *)password
{
    BOOL valid = NO;
    
    if ([password length] > 4 && !([password length] > 20)) 
    {
        valid = YES;
    }
    
    return valid;
}

- (BOOL)validateDesiredUserName:(NSString *)username
{
    BOOL valid = NO;
    
    if ([username length] > 4 && !([username length] > 20)) 
    {
        valid = YES;
    }
    
    return valid;
    
}

- (void)textFieldDidBeginEditing:(UITextField *)textField
{
    [self setActiveTextField:textField];
}

- (void)textFieldDidEndEditing:(UITextField *)textField
{
    [self validateTextField:textField];
    
}

- (void)viewDidUnload
{
    [self setAddressField:nil];
    [self setAddressLabel:nil];
    [self setUserNameLabel:nil];
    [self setUserNameField:nil];
    [self setPaswordLabel:nil];
    [self setPasswordField:nil];
    [self setJoinButton:nil];
    [self setActivityIndicator:nil];
    [self setJoinStatusLabel:nil];
    [self setAddressStatusImageView:nil];
    [self setUserNameStatusImageView:nil];
    [self setPasswordStatusImageView:nil];
    
    [super viewDidUnload];
}


- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

@end