//
//  IZFirstViewController.m
//  Instazam
//
//  Created by Isaac Schmidt on 4/11/12.
//  Copyright (c) 2012 Schmidt Consulting, LLC. All rights reserved.
//

#import "IZUploadViewController.h"
#import "UIImage+Resize.h"
#import <Parse/Parse.h>

@implementation IZUploadViewController
@synthesize imageView;
@synthesize commentField;
@synthesize chooseImageButton;
@synthesize uploadImageButton;
@synthesize activityIndicator;
@synthesize progressIndicator;
@synthesize pickerPopover;
@synthesize uploadStatusLabel;

- (IBAction)didPressChooseButton:(id)sender 
{
    UIImagePickerController *imagePicker = [[UIImagePickerController alloc] init];
    imagePicker.delegate = self;
    
    UIPopoverController *imagePickerPopover = [[UIPopoverController alloc] initWithContentViewController:imagePicker];
    self.pickerPopover = imagePickerPopover;
        
    [imagePickerPopover presentPopoverFromRect:[sender frame]
                                        inView:self.view
                      permittedArrowDirections:UIPopoverArrowDirectionAny
                                      animated:YES];
    
}

- (void)imagePickerController:(UIImagePickerController *)picker didFinishPickingImage:(UIImage *)image editingInfo:(NSDictionary *)editingInfo
{

    image = [image resizedImageWithContentMode:self.imageView.contentMode
                                                      bounds:self.imageView.bounds.size
                                        interpolationQuality:kCGInterpolationDefault];
    
    [[self imageView] setImage:image];
    [[self pickerPopover] dismissPopoverAnimated:YES];
    self.pickerPopover = nil;
    
}

- (IBAction)didPressUploadButton:(id)sender 
{
    
    PFUser *currentUser = [PFUser currentUser];
    
    if (!currentUser)
    {
        UIAlertView *userLoginAlert = [[UIAlertView alloc] initWithTitle:@"No User"
                                                                 message:@"You must be logged in with an account before you can upload an image."
                                                                delegate:nil
                                                       cancelButtonTitle:nil
                                                       otherButtonTitles:@"Ok", nil];
        [userLoginAlert show];
        
    }
    
    //Verify user provided an image and comment.
    if (!self.imageView.image || !self.commentField.text) 
    {
        UIAlertView *incompleteAlert = [[UIAlertView alloc] initWithTitle:@"Incomplete"
                                                                  message:@"You haven't included an image and comment."
                                                                 delegate:nil
                                                        cancelButtonTitle:nil
                                                        otherButtonTitles:@"Ok", nil];
        [incompleteAlert show];
    }
    
    [[self activityIndicator] startAnimating];
    [[self progressIndicator] setHidden:NO];
    [[self commentField] resignFirstResponder];
    
    //Upload File
    UIImage *uploadImage = [[self imageView] image];
    NSData *imageData = UIImagePNGRepresentation(uploadImage);
    PFFile *imageFile = [PFFile fileWithName:@"image.png" data:imageData];
    [imageFile saveInBackgroundWithBlock:^(BOOL succeeded, NSError *error) {
        
        if (error)
        {
            /*
            Error handling is slightly atypical in that we get a direct pointer to an error,
            if it's nil, the operation was successful.
             */
        }
        
        [[self activityIndicator] stopAnimating];
        [[self progressIndicator] setHidden:YES];
        
       //Handle success
        PFObject *userPhoto = [PFObject objectWithClassName:@"UserPhoto"];
        [userPhoto setValue:imageFile forKey:@"imageFile"];
        [userPhoto setValue:self.commentField.text forKey:@"imageComment"];
        [userPhoto save];
        
        dispatch_async(dispatch_get_main_queue(), ^{
            
            [[self uploadStatusLabel] setText:@"Upload complete!"];
            [[self imageView] setImage:nil];
            [[self commentField] setText:nil];
            
        });
        
    } progressBlock:^(int percentDone) {
        
        NSNumber *percentNumber = [NSNumber numberWithInt:percentDone];
        float percentFloat = ([percentNumber floatValue] / 100);
        
        [[self progressIndicator] setProgress:percentFloat];
        
    }];
}

- (void)textFieldDidEndEditing:(UITextField *)textField
{
    [textField resignFirstResponder];
}

- (void)viewDidUnload
{
    [self setImageView:nil];
    [self setCommentField:nil];
    [self setChooseImageButton:nil];
    [self setUploadImageButton:nil];
    [self setActivityIndicator:nil];
    [self setProgressIndicator:nil];
    [self setUploadStatusLabel:nil];
   
    [super viewDidUnload];
   
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return YES;
}

@end
